task — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- model »

# task

Most users have the need to do some basic task tracking across various parts of the data model.

These classes provide basic task tracking with configurable statuses, categories and roles. They are presented to the user as “Todo’s”

class `camelot.model.task.` `Task`(**kwargs)

  Fields :

  > - status : refers to Task_status
  > - due_date : <class ‘sqlalchemy.types.Date’>, not required
  > - description : VARCHAR(255), required
  > - described_by : refers to TaskType
  > - creation_date : <class ‘sqlalchemy.types.Date’>, required
  > - categories : refers to PartyCategory
  > - documents : refers to TaskDocument
  > - roles : refers to TaskRole
  > - notes : refers to TaskNote

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- model »

Comments
blog comments powered by Disqus